# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ft_sessions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ft_error_pb2 as ft__error__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
import ft_types_pb2 as ft__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x66t_sessions.proto\x12\x07\x66oxtrot\x1a\x0e\x66t_error.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x0e\x66t_types.proto\"\xb8\x01\n\x0csession_info\x12\x1f\n\x03\x65rr\x18\x01 \x01(\x0b\x32\x12.foxtrot.errstatus\x12\x11\n\tsessionid\x18\x02 \x01(\x0c\x12\x17\n\x0fuser_identifier\x18\x03 \x01(\t\x12\x0f\n\x07\x63omment\x18\x04 \x01(\t\x12\x0f\n\x07\x64\x65vices\x18\x05 \x03(\r\x12\r\n\x05\x66lags\x18\x06 \x03(\t\x12*\n\x06\x65xpiry\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"X\n\x0csession_list\x12\x1f\n\x03\x65rr\x18\x01 \x01(\x0b\x32\x12.foxtrot.errstatus\x12\'\n\x08sessions\x18\x02 \x03(\x0b\x32\x15.foxtrot.session_info2\xff\x01\n\x08sessions\x12<\n\x0cStartSession\x12\x15.foxtrot.session_info\x1a\x15.foxtrot.session_info\x12<\n\x0c\x43loseSession\x12\x15.foxtrot.session_info\x1a\x15.foxtrot.session_info\x12@\n\x10KeepAliveSession\x12\x15.foxtrot.session_info\x1a\x15.foxtrot.session_info\x12\x35\n\x0cListSessions\x12\x0e.foxtrot.empty\x1a\x15.foxtrot.session_listb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ft_sessions_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SESSION_INFO']._serialized_start=96
  _globals['_SESSION_INFO']._serialized_end=280
  _globals['_SESSION_LIST']._serialized_start=282
  _globals['_SESSION_LIST']._serialized_end=370
  _globals['_SESSIONS']._serialized_start=373
  _globals['_SESSIONS']._serialized_end=628
# @@protoc_insertion_point(module_scope)
