# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: foxtrot.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ft_error_pb2 as ft__error__pb2
import ft_types_pb2 as ft__types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rfoxtrot.proto\x12\x07\x66oxtrot\x1a\x0e\x66t_error.proto\x1a\x0e\x66t_types.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb5\x01\n\x16\x62roadcast_notification\x12\x1f\n\x03\x65rr\x18\x01 \x01(\x0b\x32\x12.foxtrot.errstatus\x12\r\n\x05msgid\x18\x02 \x01(\r\x12\x19\n\x11use_default_title\x18\x03 \x01(\x08\x12\r\n\x05title\x18\x04 \x01(\t\x12\x0c\n\x04\x62ody\x18\x05 \x01(\t\x12\x1b\n\x13use_default_channel\x18\x06 \x01(\x08\x12\x16\n\x0e\x63hannel_target\x18\x07 \x01(\t\"\xd3\x01\n\x0bserver_info\x12\x1f\n\x03\x65rr\x18\x01 \x01(\x0b\x32\x12.foxtrot.errstatus\x12\x16\n\x0eserver_version\x18\x02 \x01(\r\x12\x13\n\x0brpc_version\x18\x03 \x01(\r\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07\x63omment\x18\x05 \x01(\t\x12+\n\x07started\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0coption_flags\x18\x07 \x01(\r\x12\x14\n\x0cunique_runid\x18\x08 \x01(\x0c\x32\xcf\x01\n\texptserve\x12Y\n\x15\x42roadcastNotification\x12\x1f.foxtrot.broadcast_notification\x1a\x1f.foxtrot.broadcast_notification\x12\x35\n\rGetServerInfo\x12\x0e.foxtrot.empty\x1a\x14.foxtrot.server_info\x12\x30\n\nDisconnect\x12\x0e.foxtrot.empty\x1a\x12.foxtrot.errstatusB\x0c\n\nio.foxtrotb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'foxtrot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\nio.foxtrot'
  _globals['_BROADCAST_NOTIFICATION']._serialized_start=92
  _globals['_BROADCAST_NOTIFICATION']._serialized_end=273
  _globals['_SERVER_INFO']._serialized_start=276
  _globals['_SERVER_INFO']._serialized_end=487
  _globals['_EXPTSERVE']._serialized_start=490
  _globals['_EXPTSERVE']._serialized_end=697
# @@protoc_insertion_point(module_scope)
