# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ft_capability.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ft_types_pb2 as ft__types__pb2
import ft_error_pb2 as ft__error__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x66t_capability.proto\x12\x07\x66oxtrot\x1a\x0e\x66t_types.proto\x1a\x0e\x66t_error.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\x96\x02\n\rdevcapability\x12%\n\x02tp\x18\x01 \x01(\x0e\x32\x19.foxtrot.capability_types\x12\x0f\n\x07\x63\x61pname\x18\x02 \x01(\t\x12\r\n\x05\x63\x61pid\x18\x08 \x01(\r\x12\x10\n\x08\x61rgnames\x18\x03 \x03(\t\x12-\n\x08\x61rgtypes\x18\x04 \x03(\x0b\x32\x1b.foxtrot.variant_descriptor\x12,\n\x05rettp\x18\x05 \x01(\x0b\x32\x1b.foxtrot.variant_descriptorH\x00\x12,\n\x08vecrettp\x18\x06 \x01(\x0e\x32\x18.foxtrot.byte_data_typesH\x00\x12\x17\n\rdynamic_rettp\x18\x07 \x01(\x08H\x00\x42\x08\n\x06return\"K\n\x13\x63\x61pability_argument\x12\x10\n\x08position\x18\x01 \x01(\r\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.foxtrot.ft_variant\"\x9a\x01\n\x12\x63\x61pability_request\x12\r\n\x05msgid\x18\x01 \x01(\r\x12\r\n\x05\x64\x65vid\x18\x02 \x01(\r\x12\x0f\n\x07\x63\x61pname\x18\x03 \x01(\t\x12\r\n\x05\x63\x61pid\x18\x06 \x01(\r\x12*\n\x04\x61rgs\x18\x04 \x03(\x0b\x32\x1c.foxtrot.capability_argument\x12\x1a\n\x12\x63ontention_timeout\x18\x05 \x01(\r\"\xfd\x01\n\x13\x63\x61pability_response\x12\r\n\x05msgid\x18\x01 \x01(\r\x12\r\n\x05\x64\x65vid\x18\x02 \x01(\r\x12\x0f\n\x07\x63\x61pname\x18\x03 \x01(\t\x12\r\n\x05\x63\x61pid\x18\x07 \x01(\r\x12&\n\treturnval\x18\x04 \x01(\x0b\x32\x13.foxtrot.ft_variant\x12\x1f\n\x03\x65rr\x18\x05 \x01(\x0b\x32\x12.foxtrot.errstatus\x12*\n\x06tstamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0ftstamp_dispatch\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa8\x01\n\rchunk_request\x12\r\n\x05msgid\x18\x01 \x01(\r\x12\r\n\x05\x64\x65vid\x18\x02 \x01(\r\x12\x0f\n\x07\x63\x61pname\x18\x03 \x01(\t\x12\r\n\x05\x63\x61pid\x18\x08 \x01(\r\x12*\n\x04\x61rgs\x18\x04 \x03(\x0b\x32\x1c.foxtrot.capability_argument\x12\x11\n\tchunksize\x18\x06 \x01(\r\x12\x1a\n\x12\x63ontention_timeout\x18\x07 \x01(\r\"\x9f\x01\n\tdatachunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\r\n\x05msgid\x18\x02 \x01(\r\x12\r\n\x05\x64\x65vid\x18\x03 \x01(\r\x12\r\n\x05\x63\x61pid\x18\x08 \x01(\r\x12\x0f\n\x07\x63\x61pname\x18\x04 \x01(\t\x12\x1f\n\x03\x65rr\x18\x06 \x01(\x0b\x32\x12.foxtrot.errstatus\x12%\n\x03\x64tp\x18\x07 \x01(\x0e\x32\x18.foxtrot.byte_data_types\"\xa0\x01\n\x0e\x62ulkdata_chunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12%\n\x03\x64tp\x18\x02 \x01(\x0e\x32\x18.foxtrot.byte_data_types\x12\x1f\n\x03\x65rr\x18\x03 \x01(\x0b\x32\x12.foxtrot.errstatus\x12\x15\n\rcpp_type_name\x18\x04 \x01(\t\x12\x0f\n\x07pagenum\x18\x05 \x01(\r\x12\x10\n\x08totalnum\x18\x06 \x01(\r\"M\n\x10\x62ulkdata_request\x12&\n\x06handle\x18\x01 \x01(\x0b\x32\x16.foxtrot.handlechooser\x12\x11\n\tchunksize\x18\x02 \x01(\r\"g\n\x0b\x64\x65vdescribe\x12\r\n\x05\x64\x65vid\x18\x01 \x01(\r\x12\x0f\n\x07\x64\x65vtype\x18\x02 \x01(\t\x12\x12\n\ndevcomment\x18\x03 \x01(\t\x12$\n\x04\x63\x61ps\x18\x04 \x03(\x0b\x32\x16.foxtrot.devcapability\"\xe0\x01\n\x0cservdescribe\x12\x13\n\x0bservcomment\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12>\n\rdevs_attached\x18\x02 \x03(\x0b\x32\'.foxtrot.servdescribe.DevsAttachedEntry\x12\x1f\n\x03\x65rr\x18\x03 \x01(\x0b\x32\x12.foxtrot.errstatus\x1aI\n\x11\x44\x65vsAttachedEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.foxtrot.devdescribe:\x02\x38\x01\"\x1e\n\rdevicechooser\x12\r\n\x05\x64\x65vid\x18\x01 \x01(\r\"k\n\x14\x64\x65vice_setup_request\x12\x13\n\x0b\x64\x65vtypename\x18\x01 \x01(\t\x12\x12\n\ndevcomment\x18\x02 \x01(\t\x12*\n\x04\x61rgs\x18\x03 \x03(\x0b\x32\x1c.foxtrot.capability_argument\"[\n\x15\x64\x65vice_setup_response\x12\x1f\n\x03\x65rr\x18\x01 \x01(\x0b\x32\x12.foxtrot.errstatus\x12!\n\x03\x64\x65v\x18\x02 \x01(\x0b\x32\x14.foxtrot.devdescribe\"6\n\rhandlechooser\x12\x0e\n\x06handle\x18\x01 \x01(\x04\x12\x15\n\rcpp_type_name\x18\x02 \x01(\t\"5\n\nhandlelist\x12\'\n\x07handles\x18\x01 \x03(\x0b\x32\x16.foxtrot.handlechooser\"\x96\x01\n\x0estream_control\x12(\n\x03req\x18\x01 \x01(\x0b\x32\x1b.foxtrot.capability_request\x12-\n\x03\x63md\x18\x02 \x01(\x0e\x32 .foxtrot.stream_control_commands\x12+\n\x08interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"g\n\rasync_control\x12(\n\x03req\x18\x01 \x01(\x0b\x32\x1b.foxtrot.capability_request\x12,\n\x03\x63md\x18\x02 \x01(\x0e\x32\x1f.foxtrot.async_control_commands\"J\n\x0e\x61sync_response\x12\x0c\n\x04\x64one\x18\x01 \x01(\x08\x12*\n\x04resp\x18\x02 \x01(\x0b\x32\x1c.foxtrot.capability_response*d\n\x10\x63\x61pability_types\x12\x12\n\x0eVALUE_READONLY\x10\x00\x12\x13\n\x0fVALUE_READWRITE\x10\x01\x12\n\n\x06\x41\x43TION\x10\x02\x12\n\n\x06STREAM\x10\x03\x12\x0f\n\x0b\x43ONSTRUCTOR\x10\x04*.\n\x17stream_control_commands\x12\x08\n\x04stop\x10\x00\x12\t\n\x05start\x10\x01*R\n\x16\x61sync_control_commands\x12\x0c\n\x08\x64ispatch\x10\x00\x12\t\n\x05\x63heck\x10\x01\x12\x07\n\x03get\x10\x02\x12\t\n\x05\x64\x65\x66\x65r\x10\x03\x12\x0b\n\x07run_all\x10\x04\x32\xe1\x05\n\ncapability\x12M\n\x10InvokeCapability\x12\x1b.foxtrot.capability_request\x1a\x1c.foxtrot.capability_response\x12\x37\n\x0e\x44\x65scribeServer\x12\x0e.foxtrot.empty\x1a\x15.foxtrot.servdescribe\x12\x39\n\tFetchData\x12\x16.foxtrot.chunk_request\x1a\x12.foxtrot.datachunk0\x01\x12\x39\n\x0b\x43loseDevice\x12\x16.foxtrot.devicechooser\x1a\x12.foxtrot.errstatus\x12\x33\n\rRescanDevices\x12\x0e.foxtrot.empty\x1a\x12.foxtrot.errstatus\x12L\n\x0bSetupDevice\x12\x1d.foxtrot.device_setup_request\x1a\x1e.foxtrot.device_setup_response\x12\x32\n\x0bListHandles\x12\x0e.foxtrot.empty\x1a\x13.foxtrot.handlelist\x12;\n\rDisposeHandle\x12\x16.foxtrot.handlechooser\x1a\x12.foxtrot.errstatus\x12M\n\x10StreamCapability\x12\x17.foxtrot.stream_control\x1a\x1c.foxtrot.capability_response(\x01\x30\x01\x12H\n\x10\x42ulkDataDownload\x12\x19.foxtrot.bulkdata_request\x1a\x17.foxtrot.bulkdata_chunk0\x01\x12H\n\x11InvokeServerAsync\x12\x16.foxtrot.async_control\x1a\x17.foxtrot.async_response(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ft_capability_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _SERVDESCRIBE_DEVSATTACHEDENTRY._options = None
  _SERVDESCRIBE_DEVSATTACHEDENTRY._serialized_options = b'8\001'
  _globals['_CAPABILITY_TYPES']._serialized_start=2486
  _globals['_CAPABILITY_TYPES']._serialized_end=2586
  _globals['_STREAM_CONTROL_COMMANDS']._serialized_start=2588
  _globals['_STREAM_CONTROL_COMMANDS']._serialized_end=2634
  _globals['_ASYNC_CONTROL_COMMANDS']._serialized_start=2636
  _globals['_ASYNC_CONTROL_COMMANDS']._serialized_end=2718
  _globals['_DEVCAPABILITY']._serialized_start=130
  _globals['_DEVCAPABILITY']._serialized_end=408
  _globals['_CAPABILITY_ARGUMENT']._serialized_start=410
  _globals['_CAPABILITY_ARGUMENT']._serialized_end=485
  _globals['_CAPABILITY_REQUEST']._serialized_start=488
  _globals['_CAPABILITY_REQUEST']._serialized_end=642
  _globals['_CAPABILITY_RESPONSE']._serialized_start=645
  _globals['_CAPABILITY_RESPONSE']._serialized_end=898
  _globals['_CHUNK_REQUEST']._serialized_start=901
  _globals['_CHUNK_REQUEST']._serialized_end=1069
  _globals['_DATACHUNK']._serialized_start=1072
  _globals['_DATACHUNK']._serialized_end=1231
  _globals['_BULKDATA_CHUNK']._serialized_start=1234
  _globals['_BULKDATA_CHUNK']._serialized_end=1394
  _globals['_BULKDATA_REQUEST']._serialized_start=1396
  _globals['_BULKDATA_REQUEST']._serialized_end=1473
  _globals['_DEVDESCRIBE']._serialized_start=1475
  _globals['_DEVDESCRIBE']._serialized_end=1578
  _globals['_SERVDESCRIBE']._serialized_start=1581
  _globals['_SERVDESCRIBE']._serialized_end=1805
  _globals['_SERVDESCRIBE_DEVSATTACHEDENTRY']._serialized_start=1732
  _globals['_SERVDESCRIBE_DEVSATTACHEDENTRY']._serialized_end=1805
  _globals['_DEVICECHOOSER']._serialized_start=1807
  _globals['_DEVICECHOOSER']._serialized_end=1837
  _globals['_DEVICE_SETUP_REQUEST']._serialized_start=1839
  _globals['_DEVICE_SETUP_REQUEST']._serialized_end=1946
  _globals['_DEVICE_SETUP_RESPONSE']._serialized_start=1948
  _globals['_DEVICE_SETUP_RESPONSE']._serialized_end=2039
  _globals['_HANDLECHOOSER']._serialized_start=2041
  _globals['_HANDLECHOOSER']._serialized_end=2095
  _globals['_HANDLELIST']._serialized_start=2097
  _globals['_HANDLELIST']._serialized_end=2150
  _globals['_STREAM_CONTROL']._serialized_start=2153
  _globals['_STREAM_CONTROL']._serialized_end=2303
  _globals['_ASYNC_CONTROL']._serialized_start=2305
  _globals['_ASYNC_CONTROL']._serialized_end=2408
  _globals['_ASYNC_RESPONSE']._serialized_start=2410
  _globals['_ASYNC_RESPONSE']._serialized_end=2484
  _globals['_CAPABILITY']._serialized_start=2721
  _globals['_CAPABILITY']._serialized_end=3458
# @@protoc_insertion_point(module_scope)
