# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import ft_sessions_pb2 as ft__sessions__pb2
import ft_types_pb2 as ft__types__pb2


class sessionsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StartSession = channel.unary_unary(
                '/foxtrot.sessions/StartSession',
                request_serializer=ft__sessions__pb2.session_info.SerializeToString,
                response_deserializer=ft__sessions__pb2.session_info.FromString,
                )
        self.CloseSession = channel.unary_unary(
                '/foxtrot.sessions/CloseSession',
                request_serializer=ft__sessions__pb2.session_info.SerializeToString,
                response_deserializer=ft__sessions__pb2.session_info.FromString,
                )
        self.KeepAliveSession = channel.unary_unary(
                '/foxtrot.sessions/KeepAliveSession',
                request_serializer=ft__sessions__pb2.session_info.SerializeToString,
                response_deserializer=ft__sessions__pb2.session_info.FromString,
                )
        self.ListSessions = channel.unary_unary(
                '/foxtrot.sessions/ListSessions',
                request_serializer=ft__types__pb2.empty.SerializeToString,
                response_deserializer=ft__sessions__pb2.session_list.FromString,
                )


class sessionsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def StartSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CloseSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def KeepAliveSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSessions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_sessionsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StartSession': grpc.unary_unary_rpc_method_handler(
                    servicer.StartSession,
                    request_deserializer=ft__sessions__pb2.session_info.FromString,
                    response_serializer=ft__sessions__pb2.session_info.SerializeToString,
            ),
            'CloseSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CloseSession,
                    request_deserializer=ft__sessions__pb2.session_info.FromString,
                    response_serializer=ft__sessions__pb2.session_info.SerializeToString,
            ),
            'KeepAliveSession': grpc.unary_unary_rpc_method_handler(
                    servicer.KeepAliveSession,
                    request_deserializer=ft__sessions__pb2.session_info.FromString,
                    response_serializer=ft__sessions__pb2.session_info.SerializeToString,
            ),
            'ListSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSessions,
                    request_deserializer=ft__types__pb2.empty.FromString,
                    response_serializer=ft__sessions__pb2.session_list.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'foxtrot.sessions', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class sessions(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def StartSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/foxtrot.sessions/StartSession',
            ft__sessions__pb2.session_info.SerializeToString,
            ft__sessions__pb2.session_info.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CloseSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/foxtrot.sessions/CloseSession',
            ft__sessions__pb2.session_info.SerializeToString,
            ft__sessions__pb2.session_info.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def KeepAliveSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/foxtrot.sessions/KeepAliveSession',
            ft__sessions__pb2.session_info.SerializeToString,
            ft__sessions__pb2.session_info.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/foxtrot.sessions/ListSessions',
            ft__types__pb2.empty.SerializeToString,
            ft__sessions__pb2.session_list.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
