# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ft_types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x66t_types.proto\x12\x07\x66oxtrot\x1a\x1fgoogle/protobuf/timestamp.proto\"\x07\n\x05\x65mpty\"\xb7\x03\n\x12variant_descriptor\x12,\n\x0cvariant_type\x18\x01 \x01(\x0e\x32\x16.foxtrot.variant_types\x12\x34\n\x10simplevalue_type\x18\x02 \x01(\x0e\x32\x1a.foxtrot.simplevalue_types\x12\x1a\n\x12simplevalue_sizeof\x18\x03 \x01(\r\x12/\n\x0bstruct_desc\x18\x04 \x01(\x0b\x32\x1a.foxtrot.struct_descriptor\x12+\n\tenum_desc\x18\x05 \x01(\x0b\x32\x18.foxtrot.enum_descriptor\x12-\n\ntuple_desc\x18\x06 \x01(\x0b\x32\x19.foxtrot.tuple_descriptor\x12\x39\n\x10homog_array_desc\x18\x07 \x01(\x0b\x32\x1f.foxtrot.homog_array_descriptor\x12-\n\nunion_desc\x18\t \x01(\x0b\x32\x19.foxtrot.union_descriptor\x12\x15\n\rcpp_type_name\x18\x08 \x01(\t\x12\x13\n\x0bis_nullable\x18\n \x01(\x08\"\xb6\x01\n\x11struct_descriptor\x12\x13\n\x0bstruct_name\x18\x01 \x01(\t\x12=\n\nstruct_map\x18\x02 \x03(\x0b\x32).foxtrot.struct_descriptor.StructMapEntry\x1aM\n\x0eStructMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.foxtrot.variant_descriptor:\x02\x38\x01\"\x8d\x01\n\x0f\x65num_descriptor\x12\x11\n\tenum_name\x18\x01 \x01(\t\x12\x37\n\x08\x65num_map\x18\x02 \x03(\x0b\x32%.foxtrot.enum_descriptor.EnumMapEntry\x1a.\n\x0c\x45numMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\"B\n\x10tuple_descriptor\x12.\n\ttuple_map\x18\x01 \x03(\x0b\x32\x1b.foxtrot.variant_descriptor\"u\n\x16homog_array_descriptor\x12\x16\n\x0ehas_fixed_size\x18\x03 \x01(\x08\x12\x12\n\nfixed_size\x18\x04 \x01(\x04\x12/\n\nvalue_type\x18\x06 \x01(\x0b\x32\x1b.foxtrot.variant_descriptor\"G\n\x10union_descriptor\x12\x33\n\x0epossible_types\x18\x01 \x03(\x0b\x32\x1b.foxtrot.variant_descriptor\"\xe7\x01\n\nft_variant\x12.\n\tsimplevar\x18\x01 \x01(\x0b\x32\x19.foxtrot.ft_simplevariantH\x00\x12\'\n\tstructval\x18\x02 \x01(\x0b\x32\x12.foxtrot.ft_structH\x00\x12#\n\x07\x65numval\x18\x03 \x01(\x0b\x32\x10.foxtrot.ft_enumH\x00\x12%\n\x08tupleval\x18\x04 \x01(\x0b\x32\x11.foxtrot.ft_tupleH\x00\x12+\n\x08\x61rrayval\x18\x05 \x01(\x0b\x32\x17.foxtrot.ft_homog_arrayH\x00\x42\x07\n\x05value\"\xdf\x01\n\x10\x66t_simplevariant\x12\x10\n\x06\x64\x62lval\x18\x01 \x01(\x01H\x00\x12\x10\n\x06intval\x18\x02 \x01(\x12H\x00\x12\x11\n\x07uintval\x18\x03 \x01(\x04H\x00\x12\x11\n\x07\x62oolval\x18\x04 \x01(\x08H\x00\x12\x13\n\tstringval\x18\x05 \x01(\tH\x00\x12/\n\ttstampval\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x13\n\thandleval\x18\t \x01(\x04H\x00\x12\x0c\n\x04size\x18\x06 \x01(\r\x12\x0f\n\x07is_void\x18\x07 \x01(\x08\x42\x07\n\x05value\"\x91\x01\n\tft_struct\x12\x13\n\x0bstruct_name\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x03(\x0b\x32\x1d.foxtrot.ft_struct.ValueEntry\x1a\x41\n\nValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.foxtrot.ft_variant:\x02\x38\x01\"E\n\x07\x66t_enum\x12&\n\x04\x64\x65sc\x18\x01 \x01(\x0b\x32\x18.foxtrot.enum_descriptor\x12\x12\n\nenum_value\x18\x02 \x01(\r\".\n\x08\x66t_tuple\x12\"\n\x05value\x18\x02 \x03(\x0b\x32\x13.foxtrot.ft_variant\"\xb7\x01\n\x0e\x66t_homog_array\x12\x36\n\x0b\x61rr_decoded\x18\x01 \x01(\x0b\x32\x1f.foxtrot.ft_homog_array_decodedH\x00\x12\x36\n\x0b\x61rr_encoded\x18\x02 \x01(\x0b\x32\x1f.foxtrot.ft_homog_array_encodedH\x00\x12,\n\tarr_heavy\x18\x03 \x01(\x0b\x32\x17.foxtrot.ft_heavy_arrayH\x00\x42\x07\n\x05\x61rray\"M\n\x16\x66t_homog_array_encoded\x12%\n\x03\x64tp\x18\x01 \x01(\x0e\x32\x18.foxtrot.byte_data_types\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"`\n\x0f\x66t_dynamic_type\x12\"\n\x05value\x18\x01 \x01(\x0b\x32\x13.foxtrot.ft_variant\x12)\n\x04\x64\x65sc\x18\x02 \x01(\x0b\x32\x1b.foxtrot.variant_descriptor\"3\n\x0e\x66t_heavy_array\x12!\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x13.foxtrot.ft_variant\"\xbb\x03\n\x16\x66t_homog_array_decoded\x12*\n\tarr_uint8\x18\x01 \x01(\x0b\x32\x15.foxtrot.ft_uint8_arrH\x00\x12,\n\narr_uint16\x18\x02 \x01(\x0b\x32\x16.foxtrot.ft_uint32_arrH\x00\x12,\n\narr_sint16\x18\x03 \x01(\x0b\x32\x16.foxtrot.ft_sint32_arrH\x00\x12,\n\narr_uint32\x18\x04 \x01(\x0b\x32\x16.foxtrot.ft_uint32_arrH\x00\x12,\n\narr_sint32\x18\x05 \x01(\x0b\x32\x16.foxtrot.ft_sint32_arrH\x00\x12,\n\narr_uint64\x18\x06 \x01(\x0b\x32\x16.foxtrot.ft_uint64_arrH\x00\x12,\n\narr_sint64\x18\x07 \x01(\x0b\x32\x16.foxtrot.ft_sint64_arrH\x00\x12*\n\tarr_float\x18\x08 \x01(\x0b\x32\x15.foxtrot.ft_float_arrH\x00\x12,\n\narr_double\x18\t \x01(\x0b\x32\x16.foxtrot.ft_double_arrH\x00\x42\x07\n\x05\x61rray\"\x1e\n\x0c\x66t_uint8_arr\x12\x0e\n\x06values\x18\x01 \x03(\r\"\x1f\n\rft_uint16_arr\x12\x0e\n\x06values\x18\x01 \x03(\r\"\x1f\n\rft_sint16_arr\x12\x0e\n\x06values\x18\x01 \x03(\x11\"\x1f\n\rft_uint32_arr\x12\x0e\n\x06values\x18\x01 \x03(\r\"\x1f\n\rft_sint32_arr\x12\x0e\n\x06values\x18\x01 \x03(\x11\"\x1f\n\rft_uint64_arr\x12\x0e\n\x06values\x18\x01 \x03(\x04\"\x1f\n\rft_sint64_arr\x12\x0e\n\x06values\x18\x01 \x03(\x12\"\x1e\n\x0c\x66t_float_arr\x12\x0e\n\x06values\x18\x01 \x03(\x02\"\x1f\n\rft_double_arr\x12\x0e\n\x06values\x18\x01 \x03(\x01*\x9e\x01\n\x11simplevalue_types\x12\x0e\n\nFLOAT_TYPE\x10\x00\x12\x0c\n\x08INT_TYPE\x10\x01\x12\x11\n\rUNSIGNED_TYPE\x10\x02\x12\r\n\tBOOL_TYPE\x10\x03\x12\x0f\n\x0bSTRING_TYPE\x10\x04\x12\r\n\tVOID_TYPE\x10\x05\x12\x11\n\rDATETIME_TYPE\x10\x06\x12\x16\n\x12REMOTE_HANDLE_TYPE\x10\x07*\xea\x01\n\x0f\x62yte_data_types\x12\x0e\n\nUCHAR_TYPE\x10\x00\x12\r\n\tCHAR_TYPE\x10\x01\x12\x0f\n\x0bUSHORT_TYPE\x10\x02\x12\r\n\tUINT_TYPE\x10\x03\x12\x0e\n\nULONG_TYPE\x10\x04\x12\x0e\n\nSHORT_TYPE\x10\x05\x12\r\n\tIINT_TYPE\x10\x06\x12\r\n\tLONG_TYPE\x10\x07\x12\x0f\n\x0b\x42\x46LOAT_TYPE\x10\x08\x12\x10\n\x0c\x42\x44OUBLE_TYPE\x10\t\x12\x11\n\rBCOMPLEX_TYPE\x10\x0b\x12\x12\n\x0e\x42\x44\x41TETIME_TYPE\x10\x0c\x12\x10\n\x0c\x42OPAQUE_TYPE\x10\r*\x8b\x01\n\rvariant_types\x12\x12\n\x0eSIMPLEVAR_TYPE\x10\x00\x12\x0f\n\x0bSTRUCT_TYPE\x10\x01\x12\r\n\tENUM_TYPE\x10\x02\x12\x0e\n\nTUPLE_TYPE\x10\x03\x12\x14\n\x10HOMOG_ARRAY_TYPE\x10\x04\x12\x0e\n\nUNION_TYPE\x10\x05\x12\x10\n\x0c\x44YNAMIC_TYPE\x10\x06\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ft_types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _STRUCT_DESCRIPTOR_STRUCTMAPENTRY._options = None
  _STRUCT_DESCRIPTOR_STRUCTMAPENTRY._serialized_options = b'8\001'
  _ENUM_DESCRIPTOR_ENUMMAPENTRY._options = None
  _ENUM_DESCRIPTOR_ENUMMAPENTRY._serialized_options = b'8\001'
  _FT_STRUCT_VALUEENTRY._options = None
  _FT_STRUCT_VALUEENTRY._serialized_options = b'8\001'
  _globals['_SIMPLEVALUE_TYPES']._serialized_start=2985
  _globals['_SIMPLEVALUE_TYPES']._serialized_end=3143
  _globals['_BYTE_DATA_TYPES']._serialized_start=3146
  _globals['_BYTE_DATA_TYPES']._serialized_end=3380
  _globals['_VARIANT_TYPES']._serialized_start=3383
  _globals['_VARIANT_TYPES']._serialized_end=3522
  _globals['_EMPTY']._serialized_start=60
  _globals['_EMPTY']._serialized_end=67
  _globals['_VARIANT_DESCRIPTOR']._serialized_start=70
  _globals['_VARIANT_DESCRIPTOR']._serialized_end=509
  _globals['_STRUCT_DESCRIPTOR']._serialized_start=512
  _globals['_STRUCT_DESCRIPTOR']._serialized_end=694
  _globals['_STRUCT_DESCRIPTOR_STRUCTMAPENTRY']._serialized_start=617
  _globals['_STRUCT_DESCRIPTOR_STRUCTMAPENTRY']._serialized_end=694
  _globals['_ENUM_DESCRIPTOR']._serialized_start=697
  _globals['_ENUM_DESCRIPTOR']._serialized_end=838
  _globals['_ENUM_DESCRIPTOR_ENUMMAPENTRY']._serialized_start=792
  _globals['_ENUM_DESCRIPTOR_ENUMMAPENTRY']._serialized_end=838
  _globals['_TUPLE_DESCRIPTOR']._serialized_start=840
  _globals['_TUPLE_DESCRIPTOR']._serialized_end=906
  _globals['_HOMOG_ARRAY_DESCRIPTOR']._serialized_start=908
  _globals['_HOMOG_ARRAY_DESCRIPTOR']._serialized_end=1025
  _globals['_UNION_DESCRIPTOR']._serialized_start=1027
  _globals['_UNION_DESCRIPTOR']._serialized_end=1098
  _globals['_FT_VARIANT']._serialized_start=1101
  _globals['_FT_VARIANT']._serialized_end=1332
  _globals['_FT_SIMPLEVARIANT']._serialized_start=1335
  _globals['_FT_SIMPLEVARIANT']._serialized_end=1558
  _globals['_FT_STRUCT']._serialized_start=1561
  _globals['_FT_STRUCT']._serialized_end=1706
  _globals['_FT_STRUCT_VALUEENTRY']._serialized_start=1641
  _globals['_FT_STRUCT_VALUEENTRY']._serialized_end=1706
  _globals['_FT_ENUM']._serialized_start=1708
  _globals['_FT_ENUM']._serialized_end=1777
  _globals['_FT_TUPLE']._serialized_start=1779
  _globals['_FT_TUPLE']._serialized_end=1825
  _globals['_FT_HOMOG_ARRAY']._serialized_start=1828
  _globals['_FT_HOMOG_ARRAY']._serialized_end=2011
  _globals['_FT_HOMOG_ARRAY_ENCODED']._serialized_start=2013
  _globals['_FT_HOMOG_ARRAY_ENCODED']._serialized_end=2090
  _globals['_FT_DYNAMIC_TYPE']._serialized_start=2092
  _globals['_FT_DYNAMIC_TYPE']._serialized_end=2188
  _globals['_FT_HEAVY_ARRAY']._serialized_start=2190
  _globals['_FT_HEAVY_ARRAY']._serialized_end=2241
  _globals['_FT_HOMOG_ARRAY_DECODED']._serialized_start=2244
  _globals['_FT_HOMOG_ARRAY_DECODED']._serialized_end=2687
  _globals['_FT_UINT8_ARR']._serialized_start=2689
  _globals['_FT_UINT8_ARR']._serialized_end=2719
  _globals['_FT_UINT16_ARR']._serialized_start=2721
  _globals['_FT_UINT16_ARR']._serialized_end=2752
  _globals['_FT_SINT16_ARR']._serialized_start=2754
  _globals['_FT_SINT16_ARR']._serialized_end=2785
  _globals['_FT_UINT32_ARR']._serialized_start=2787
  _globals['_FT_UINT32_ARR']._serialized_end=2818
  _globals['_FT_SINT32_ARR']._serialized_start=2820
  _globals['_FT_SINT32_ARR']._serialized_end=2851
  _globals['_FT_UINT64_ARR']._serialized_start=2853
  _globals['_FT_UINT64_ARR']._serialized_end=2884
  _globals['_FT_SINT64_ARR']._serialized_start=2886
  _globals['_FT_SINT64_ARR']._serialized_end=2917
  _globals['_FT_FLOAT_ARR']._serialized_start=2919
  _globals['_FT_FLOAT_ARR']._serialized_end=2949
  _globals['_FT_DOUBLE_ARR']._serialized_start=2951
  _globals['_FT_DOUBLE_ARR']._serialized_end=2982
# @@protoc_insertion_point(module_scope)
