syntax="proto3";
package foxtrot;

enum error_types
{
    ft_Error = 0;
    ft_DeviceError = 1;
    ft_ProtocolError = 2;
    out_of_range = 3;
    unknown_error = 4;
    contention_timeout = 5;
    ft_ServerError = 6;
    ft_AuthError = 7;
}

message errstatus
{
    error_types tp =1;
    string msg = 2;

}
