# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ft_auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ft_error_pb2 as ft__error__pb2
import ft_types_pb2 as ft__types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rft_auth.proto\x12\x07\x66oxtrot\x1a\x0e\x66t_error.proto\x1a\x0e\x66t_types.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"|\n\tauth_data\x12\x0e\n\x06userid\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\x0c\x12\x11\n\tauthlevel\x18\x03 \x01(\x05\x12\x11\n\tauthflags\x18\x04 \x01(\x05\x12*\n\x06\x65xpiry\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x1e\n\x0c\x61uth_request\x12\x0e\n\x06userid\x18\x01 \x01(\t\"Y\n\x0e\x61uth_challenge\x12\x1f\n\x03\x65rr\x18\x01 \x01(\x0b\x32\x12.foxtrot.errstatus\x12\x13\n\x0b\x63hallengeid\x18\x02 \x01(\r\x12\x11\n\tchallenge\x18\x03 \x01(\x0c\"A\n\rauth_response\x12\x13\n\x0b\x63hallengeid\x18\x01 \x01(\r\x12\x0e\n\x06userid\x18\x02 \x01(\t\x12\x0b\n\x03sig\x18\x03 \x01(\x0c\"f\n\x0c\x61uth_confirm\x12\x1f\n\x03\x65rr\x18\x01 \x01(\x0b\x32\x12.foxtrot.errstatus\x12\x12\n\nsessionkey\x18\x02 \x01(\x0c\x12\x0e\n\x06\x65xpiry\x18\x03 \x01(\x04\x12\x11\n\tauthlevel\x18\x04 \x01(\x05\"i\n\x0esasl_auth_data\x12\x1f\n\x03\x65rr\x18\x01 \x01(\x0b\x32\x12.foxtrot.errstatus\x12\x11\n\tsasl_data\x18\x02 \x01(\x0c\x12#\n\x07\x61uthdat\x18\x03 \x01(\x0b\x32\x12.foxtrot.auth_data\"I\n\x0e\x61uth_type_list\x12\x1f\n\x03\x65rr\x18\x01 \x01(\x0b\x32\x12.foxtrot.errstatus\x12\x16\n\x0emechanism_name\x18\x02 \x03(\t2\xe6\x02\n\x04\x61uth\x12\x46\n\x14RequestAuthChallenge\x12\x15.foxtrot.auth_request\x1a\x17.foxtrot.auth_challenge\x12\x45\n\x14RespondAuthChallenge\x12\x16.foxtrot.auth_response\x1a\x15.foxtrot.auth_confirm\x12\x45\n\x1aGetSupportedAuthMechanisms\x12\x0e.foxtrot.empty\x1a\x17.foxtrot.auth_type_list\x12G\n\x0fSaslAuthProcess\x12\x17.foxtrot.sasl_auth_data\x1a\x17.foxtrot.sasl_auth_data(\x01\x30\x01\x12?\n\x0bVerifyToken\x12\x17.foxtrot.sasl_auth_data\x1a\x17.foxtrot.sasl_auth_datab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ft_auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_AUTH_DATA']._serialized_start=91
  _globals['_AUTH_DATA']._serialized_end=215
  _globals['_AUTH_REQUEST']._serialized_start=217
  _globals['_AUTH_REQUEST']._serialized_end=247
  _globals['_AUTH_CHALLENGE']._serialized_start=249
  _globals['_AUTH_CHALLENGE']._serialized_end=338
  _globals['_AUTH_RESPONSE']._serialized_start=340
  _globals['_AUTH_RESPONSE']._serialized_end=405
  _globals['_AUTH_CONFIRM']._serialized_start=407
  _globals['_AUTH_CONFIRM']._serialized_end=509
  _globals['_SASL_AUTH_DATA']._serialized_start=511
  _globals['_SASL_AUTH_DATA']._serialized_end=616
  _globals['_AUTH_TYPE_LIST']._serialized_start=618
  _globals['_AUTH_TYPE_LIST']._serialized_end=691
  _globals['_AUTH']._serialized_start=694
  _globals['_AUTH']._serialized_end=1052
# @@protoc_insertion_point(module_scope)
